@@ -1,7 +1,4 @@
-import os
-import sys
-import asyncio
-
+# pylint:disable=(missing-function-docstring)
 from aiozoom.config import client
 from aiozoom.config.auth import Configuration
 
@@ -11,7 +8,7 @@ class Base(Configuration):
     Base class for processing requests
     """
     async def base_get_request(self, method: str, *args, **kwargs) -> dict:
-        data = await client.get(method, headers=self._headers())
+        data = await client.get(method, headers=self._headers(), *args, **kwargs)
         return data
 
     async def base_post_request(self, method: str, *args, **kwargs) -> dict:
@@ -24,7 +21,18 @@ class Base(Configuration):
             method, headers=self._headers(), *args, **kwargs)
         return data
 
-    def _headers(self) -> dict:
+    async def base_patch_request(self, method: str, *args, **kwargs) -> dict:
+        data = await client.patch(
+            method, headers=self._headers(), *args, **kwargs)
+        return data
+
+    async def base_delete_request(self, method: str, *args, **kwargs) -> dict:
+        data = await client.delete(
+            method, headers=self._headers(), *args, **kwargs)
+        return data
+
+    @staticmethod
+    def _headers() -> dict:
         return {
             'Authorization': f'Bearer {Configuration.auth_token}'
         }
